namespace CommonLayer.Nullables
{
	using System;
	using System.Xml;

	public class NullDateTime : INullable
	{
		private Boolean _not_null;
		private DateTime _value;

		public NullDateTime( Object Value )
		{
			if( ! Convert.IsDBNull( Value ) )
			{
                this._value = Convert.ToDateTime( Value );
				this._not_null = true;
			}
			else
			{
				this._value = new DateTime( 1900, 1, 1 );
				this._not_null = false;
			}
		}

		public DateTime Value
		{
			get
			{
				if( ! this._not_null )
					throw new NullReferenceException();

				return this._value;
			}
		}
		
		public static NullDateTime Empty
		{
			get { return new NullDateTime( DBNull.Value ); }
		}

		public static NullDateTime Create( Object Value )
		{
			return new NullDateTime( Value );
		}

		public static NullDateTime Create( XmlNode Node )
		{
			if( Node == null )
				return Empty;

			return new NullDateTime( Node.InnerText );
		}

		#region INullable Members

		public Boolean NotNull
		{
			get
			{
				return this._not_null;
			}
		}

		public Object DBNullable
		{
			get
			{
				if( ! this._not_null )
					return DBNull.Value;

				return this._value;
			}
		}

		public String UINullable
		{
			get
			{
				if( ! this._not_null )
					return String.Empty;

				return this._value.ToString();
			}
		}

		#endregion
	}
}
