namespace CommonLayer.Nullables
{
	using System;
	using System.Xml;

	public struct NullInt32 : INullable
	{
		private Boolean _not_null;
		private Int32 _value;

		public NullInt32( Object Value )
		{
			if( ! Convert.IsDBNull( Value ) )
			{
				this._value = Convert.ToInt32( Value );
				this._not_null = true;
			}
			else
			{
				this._value = 0;
				this._not_null = false;
			}
		}

		public Int32 Value
		{
			get
			{
				if( ! this._not_null )
					throw new NullReferenceException();

				return this._value; 
			}
		}

		public static NullInt32 Empty
		{
			get { return new NullInt32( DBNull.Value ); }
		}

		public static NullInt32 Create( Object Value )
		{
			return new NullInt32( Value );
		}

		public static NullInt32 Create( XmlNode Node )
		{
			if( Node == null )
				return Empty;

			return new NullInt32( Node.InnerText );
		}

		#region INullable Members

		public Boolean NotNull
		{
			get { return this._not_null; }
		}

		public Object DBNullable
		{
			get
			{
				if( ! this._not_null )
					return DBNull.Value;

				return this._value;
			}
		}

		public String UINullable
		{
			get
			{
				if( ! this._not_null )
					return String.Empty;

				return this._value.ToString();;
			}
		}

		#endregion
	}
}