namespace CommonLayer.Nullables
{
	using System;
	using System.Xml;

	public struct NullString : INullable 
	{
		private Boolean _not_null;
		private String _value;

		public NullString( Object Value )
		{
			if( ! Convert.IsDBNull( Value ) )
			{
				this._value = Convert.ToString( Value );
				this._not_null = true;
			}
			else
			{
				this._value = String.Empty;
				this._not_null = false;
			}
		}

		public String Value
		{
			get
			{
				if( ! this._not_null )
					throw new NullReferenceException();

				return this._value; 
			}
		}	

		public static NullString Empty
		{
			get { return new NullString( DBNull.Value ); }
		}

		public static NullString Create( Object Value )
		{
            return new NullString( Value );
		}

		public static NullString Create( XmlNode Node )
		{
			if( Node == null )
				return Empty;

            return new NullString( Node.InnerText );
		}

		#region INullable Members

		public Boolean NotNull
		{
			get { return this._not_null; }
		}

		public Object DBNullable
		{
			get
			{
				if( ! this._not_null )
					return DBNull.Value;

				return this._value;
			}
		}

		public String UINullable
		{
			get
			{
				if( ! this._not_null )
					return String.Empty;

				return this._value;
			}
		}

		#endregion
	}
}