namespace DataLayer.Primitive
{
	using System;

	using Core;
	using CommonLayer.Customs;

	public abstract class PrimitiveEntity
	{
		private String _name;
		protected PrimitiveParameterCollection _collection;

		public PrimitiveEntity( String Name )
		{
			this._name = Name;
			this._collection = new PrimitiveParameterCollection();
		}

		protected virtual void OnInsert() {}

		protected virtual void OnUpdate() {}

		protected virtual void OnDelete() {}

		protected virtual void OnSelect() {}

		private void ExecuteNonQuery( String Store )
		{
            PrimitiveHelper.ExecuteNonQuery( new PrimitiveProcedure( Store, "" ), this._collection );
		}

		private CustomDataSet ExecuteDataSet( String Store )
		{
            return PrimitiveHelper.ExecuteDataSet( new PrimitiveProcedure( Store, this._name ), this._collection );
		}

		protected void InnerInsert()
		{
			this._collection.Clear();
			this.OnInsert();
			this.ExecuteNonQuery( "p_" + this._name + "_insert" );
		}

		protected void InnerUpdate()
		{
			this._collection.Clear();
			this.OnUpdate();
            this.ExecuteNonQuery( "p_" + this._name + "_update" );
		}

		protected void InnerDelete()
		{
			this._collection.Clear();
			this.OnDelete();
			this.ExecuteNonQuery( "p_" + this._name + "_delete" );
		}

		protected CustomDataSet InnerSelect()
		{
			this._collection.Clear();
			this.OnSelect();
			return ExecuteDataSet( "p_" + this._name + "_select" );
		}
	}
}
