namespace DataLayer.Primitive
{
	using System;
	using System.Data;
	using System.Data.SqlClient;
	using CommonLayer.Nullables;

	public class PrimitiveParameter
	{
		private SqlParameter _parameter;

		public PrimitiveParameter()
		{
		}

		private PrimitiveParameter( String Name, Object Value, Int32 Size, ParameterDirection Direction, SqlDbType Type, Boolean Nullable )
		{
			this._parameter = new SqlParameter( Name, Type, Size );
			this._parameter.IsNullable = Nullable;
			this._parameter.Direction = Direction;
			this._parameter.Value = Value;
		}

		public SqlParameter Parameter
		{
			get { return this._parameter; }
		}

		public String Name
		{
			get { return this._parameter.ParameterName; }
		}

		public Object Value
		{
			get { return this._parameter.Value; }
		}

		public static PrimitiveParameter CreateOutputInt32(
			String Name )
		{
			return new PrimitiveParameter( Name, null, 8, ParameterDirection.Output, SqlDbType.Int, false );
		}

		public static PrimitiveParameter CreateInput(
			String Name,
			Int32 Value )
		{
			return new PrimitiveParameter( Name, Value, 8, ParameterDirection.Input, SqlDbType.Int, false );
		}

		public static PrimitiveParameter CreateInput(
			String Name,
			NullInt32 Value )
		{
			return new PrimitiveParameter( Name, Value.DBNullable, 8, ParameterDirection.Input, SqlDbType.Int, true );
		}

		public static PrimitiveParameter CreateInput(
			String Name,
			String Value,
			Int32 Size )
		{
			return new PrimitiveParameter( Name, Value, Size, ParameterDirection.Input, SqlDbType.VarChar, false );
		}

		public static PrimitiveParameter CreateInput(
			String Name,
			NullString Value,
			Int32 Size )
		{
			return new PrimitiveParameter( Name, Value.DBNullable, Size, ParameterDirection.Input, SqlDbType.VarChar, true );
		}

		public static PrimitiveParameter CreateInput(
			String Name,
			DateTime Value )
		{
			return new PrimitiveParameter( Name, Value, 8, ParameterDirection.Input, SqlDbType.DateTime, false );
		}

		public static PrimitiveParameter CreateInput(
			String Name,
			NullDateTime Value )
		{
			return new PrimitiveParameter( Name, Value.DBNullable, 8, ParameterDirection.Input, SqlDbType.DateTime, true );
		}

		public static PrimitiveParameter CreateInput(
			String Name,
			Boolean Value )
		{
			return new PrimitiveParameter( Name, Value, 1, ParameterDirection.Input, SqlDbType.Bit,  false );
		}
	}
}